======
Phileo
======

.. image:: https://img.shields.io/travis/pinax/phileo.svg
    :target: https://travis-ci.org/pinax/phileo

.. image:: https://img.shields.io/coveralls/pinax/phileo.svg
    :target: https://coveralls.io/r/pinax/phileo

.. image:: https://img.shields.io/pypi/dm/phileo.svg
    :target:  https://pypi.python.org/pypi/phileo/

.. image:: https://img.shields.io/pypi/v/phileo.svg
    :target:  https://pypi.python.org/pypi/phileo/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/phileo/


A liking app


Documentation
-------------

Documentation can be found online at http://phileo.readthedocs.org/.
